@@ -6,6 +6,7 @@ Fields to be used with dirty_models
 from datetime import datetime, date, time
 from dateutil.parser import parse as dateutil_parse
 from .model_types import ListModel
+from collections import Mapping
 
 
 class BaseField:
@@ -68,10 +69,10 @@ class BaseField:
         obj.delete_field_value(self.name)
 
     def __get__(self, obj, cls=None):
-        if self._getter:
-            return self._getter(self, obj, cls)
         if obj is None:
             return self
+        if self._getter:
+            return self._getter(self, obj, cls)
         if self._name is None:
             raise AttributeError("Field name must be set")
         return self.get_value(obj)
@@ -201,10 +202,13 @@ class TimeField(DateTimeBaseField):
         elif isinstance(value, int):
             return self.convert_value(datetime.fromtimestamp(value))
         elif isinstance(value, str):
-            if not self.parse_format:
-                value = dateutil_parse(value)
-                return value.time()
-            return self.convert_value(datetime.strptime(value, self.parse_format))
+            try:
+                if not self.parse_format:
+                    value = dateutil_parse(value)
+                    return value.time()
+                return self.convert_value(datetime.strptime(value, self.parse_format))
+            except ValueError:
+                return None
         elif isinstance(value, datetime):
             return value.timetz()
 
@@ -227,10 +231,13 @@ class DateField(DateTimeBaseField):
         elif isinstance(value, int):
             return self.convert_value(datetime.fromtimestamp(value))
         elif isinstance(value, str):
-            if not self.parse_format:
-                value = dateutil_parse(value)
-                return value.date()
-            return self.convert_value(datetime.strptime(value, self.parse_format))
+            try:
+                if not self.parse_format:
+                    value = dateutil_parse(value)
+                    return value.date()
+                return self.convert_value(datetime.strptime(value, self.parse_format))
+            except ValueError:
+                return None
         elif isinstance(value, datetime):
             return value.date()
 
@@ -253,9 +260,12 @@ class DateTimeField(DateTimeBaseField):
         elif isinstance(value, int):
             return datetime.fromtimestamp(value)
         elif isinstance(value, str):
-            if not self.parse_format:
-                return dateutil_parse(value)
-            return datetime.strptime(value, self.parse_format)
+            try:
+                if not self.parse_format:
+                    return dateutil_parse(value)
+                return datetime.strptime(value, self.parse_format)
+            except ValueError:
+                return None
         elif isinstance(value, date):
             return datetime(year=value.year, month=value.month,
                             day=value.day)
@@ -308,7 +318,7 @@ class ModelField(BaseField):
         return isinstance(value, self._model_class)
 
     def can_use_value(self, value):
-        return isinstance(value, dict)
+        return isinstance(value, (dict, Mapping))
 
     def __set__(self, obj, value):
         if self._model_setter:
