@@ -10,6 +10,7 @@ from datetime import datetime
 from dirty_models.model_types import ListModel
 from dirty_models.base import BaseData
 import itertools
+from collections import Mapping
 
 
 class DirtyModelMeta(type):
@@ -84,7 +85,7 @@ class BaseModel(BaseData, metaclass=DirtyModelMeta):
         self._deleted_fields = []
 
         self.unlock()
-        if isinstance(data, dict):
+        if isinstance(data, (dict, Mapping)):
             self.import_data(data)
         self.import_data(kwargs)
         if flat:
@@ -103,17 +104,18 @@ class BaseModel(BaseData, metaclass=DirtyModelMeta):
         """
         Set the value to the field modified_data
         """
-        if self._can_write_field(name):
+        obj = self.__class__.get_field_obj(name)
 
-            if name in self._deleted_fields:
-                self._deleted_fields.remove(name)
-            if self._original_data.get(name) == value:
-                if self._modified_data.get(name):
-                    self._modified_data.pop(name)
+        if self._can_write_field(obj.name):
+            if obj.name in self._deleted_fields:
+                self._deleted_fields.remove(obj.name)
+            if self._original_data.get(obj.name) == value:
+                if self._modified_data.get(obj.name):
+                    self._modified_data.pop(obj.name)
             else:
-                self._modified_data[name] = value
+                self._modified_data[obj.name] = value
                 self._prepare_child(value)
-                if name in self._read_only_fields:
+                if obj.name in self._read_only_fields:
                     try:
                         value.set_read_only(True)
                     except AttributeError:
@@ -123,37 +125,40 @@ class BaseModel(BaseData, metaclass=DirtyModelMeta):
         """
         Get the field value from the modified data or the original one
         """
-        if name in self._deleted_fields:
+        obj = self.__class__.get_field_obj(name)
+        if obj.name in self._deleted_fields:
             return None
-        modified = self._modified_data.get(name)
+        modified = self._modified_data.get(obj.name)
         if modified is not None:
             return modified
-        return self._original_data.get(name)
+        return self._original_data.get(obj.name)
 
     def delete_field_value(self, name):
         """
         Mark this field to be deleted
         """
-        if self._can_write_field(name):
-            if name in self._modified_data:
-                self._modified_data.pop(name)
+        obj = self.__class__.get_field_obj(name)
+        if self._can_write_field(obj.name):
+            if obj.name in self._modified_data:
+                self._modified_data.pop(obj.name)
 
-            if name in self._original_data:
-                self._deleted_fields.append(name)
+            if obj.name in self._original_data:
+                self._deleted_fields.append(obj.name)
 
     def reset_field_value(self, name):
         """
         Resets value of a field
         """
-        if self._can_write_field(name):
-            if name in self._modified_data:
-                del self._modified_data[name]
+        obj = self.__class__.get_field_obj(name)
+        if self._can_write_field(obj.name):
+            if obj.name in self._modified_data:
+                del self._modified_data[obj.name]
 
-            if name in self._deleted_fields:
-                self._deleted_fields.remove(name)
+            if obj.name in self._deleted_fields:
+                self._deleted_fields.remove(obj.name)
 
             try:
-                self._original_data[name].clear_modified_data()
+                self._original_data[obj.name].clear_modified_data()
             except (KeyError, AttributeError):
                 pass
 
@@ -161,11 +166,12 @@ class BaseModel(BaseData, metaclass=DirtyModelMeta):
         """
         Returns whether a field is modified or not
         """
-        if name in self._modified_data or name in self._deleted_fields:
+        obj = self.__class__.get_field_obj(name)
+        if obj.name in self._modified_data or obj.name in self._deleted_fields:
             return True
 
         try:
-            return self.get_field_value(name).is_modified()
+            return self.get_field_value(obj.name).is_modified()
         except AttributeError:
             return False
 
@@ -176,7 +182,7 @@ class BaseModel(BaseData, metaclass=DirtyModelMeta):
         if not self.get_read_only() or not self.is_locked():
             if isinstance(data, BaseModel):
                 data = data.export_data()
-            if isinstance(data, dict):
+            if isinstance(data, (dict, Mapping)):
                 for key, value in data.items():
                     if hasattr(self, key):
                         setattr(self, key, value)
@@ -374,6 +380,59 @@ class BaseModel(BaseData, metaclass=DirtyModelMeta):
     def __str__(self):
         return self.__class__.__name__ + '({0})'.format(str(self.export_data()))
 
+    @classmethod
+    def get_field_obj(cls, name):
+        return getattr(cls, name, None)
+
+    def _get_fields_by_path(self, field):
+        """
+        Function to perform a function to the field specified. If the function has to be performed by the same object
+        the field name is retrieved
+        :param field: Field structure as following:
+         field_1.*.subfield_2  would apply a the function to the every subfield_2 of the elements in field_1
+         field_1.1.subfield_2  would apply a the function to the subfield_2 of the element 1 in field_1
+        :field function: string containing the function in the class to be applied to the field
+        """
+        try:
+            field, next_field = field.split('.', 1)
+        except ValueError:
+            next_field = ''
+
+        if field == '*':
+            return self.get_fields(), next_field
+        else:
+            return [field], next_field
+
+    def delete_attr_by_path(self, field):
+        """
+        Function for deleting a field specifying the path in the whole model as described
+        in :func:`dirty:models.models.BaseModel.perform_function_by_path`
+        """
+        fields, next_field = self._get_fields_by_path(field)
+        for field in fields:
+            if next_field:
+                try:
+                    self.get_field_value(field).delete_attr_by_path(next_field)
+                except AttributeError:
+                    pass
+            else:
+                self.delete_field_value(field)
+
+    def reset_attr_by_path(self, field):
+        """
+        Function for restoring a field specifying the path in the whole model as described
+        in :func:`dirty:models.models.BaseModel.perform_function_by_path`
+        """
+        fields, next_field = self._get_fields_by_path(field)
+        for field in fields:
+            if next_field:
+                try:
+                    self.get_field_value(field).reset_attr_by_path(next_field)
+                except AttributeError:
+                    pass
+            else:
+                self.reset_field_value(field)
+
 
 class DynamicModel(BaseModel):
 
@@ -435,6 +494,8 @@ class DynamicModel(BaseModel):
                 return None
             field_type = self._get_field_type(None, value[0])
             return ArrayField(name=key, field_type=field_type)
+        elif value is None:
+            return None
         else:
             raise TypeError("Invalid parameter: %s. Type not supported." % (key,))
 
